=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2005-12-22 03:14:27 +0000
+++ bzrlib/__init__.py	2006-01-03 15:33:37 +0000
@@ -95,7 +95,10 @@
 
 
 def get_bzr_revision():
-    """If bzr is run from a branch, return (revno,revid) or None"""
+    """If bzr is run from a branch, return (revno,revid) or None
+
+    deprecated in bzr 0.7
+    """
     import bzrlib.errors
     from bzrlib.branch import Branch
     

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2005-12-18 04:08:46 +0000
+++ bzrlib/builtins.py	2006-01-03 15:10:11 +0000
@@ -1461,12 +1461,31 @@
             bzrlib.ui.ui_factory = save_ui
 
 
+def _get_bzr_branch():
+    """If bzr is run from a branch, return Branch or None"""
+    import bzrlib.errors
+    from bzrlib.branch import Branch
+    from bzrlib.osutils import abspath
+    from os.path import dirname
+    
+    try:
+        branch = Branch.open(dirname(abspath(dirname(__file__))))
+        return branch
+    except bzrlib.errors.BzrError:
+        return None
+    
+
 def show_version():
     print "bzr (bazaar-ng) %s" % bzrlib.__version__
     # is bzrlib itself in a branch?
-    bzrrev = bzrlib.get_bzr_revision()
-    if bzrrev:
-        print "  (bzr checkout, revision %d {%s})" % bzrrev
+    branch = _get_bzr_branch()
+    if branch:
+        rh = branch.revision_history()
+        revno = len(rh)
+        print "  bzr checkout, revision %d" % (revno,)
+        print "  nick: %s" % (branch.nick,)
+        if rh:
+            print "  revid: %s" % (rh[-1],)
     print bzrlib.__copyright__
     print "http://bazaar-ng.org/"
     print

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-12-19 17:36:44 +0000
+++ bzrlib/errors.py	2006-01-03 15:44:18 +0000
@@ -34,8 +34,9 @@
 ... except:
 ...   print sys.exc_type
 ...   print sys.exc_value
-...   if hasattr(sys.exc_value, 'path'):
-...     print sys.exc_value.path
+...   path = getattr(sys.exc_value, 'path')
+...   if path is not None:
+...     print path
 bzrlib.errors.NotBranchError
 Not a branch: /foo/bar
 /foo/bar

=== modified file 'bzrlib/export/dir_exporter.py'
--- bzrlib/export/dir_exporter.py	2005-11-14 23:58:51 +0000
+++ bzrlib/export/dir_exporter.py	2005-12-29 03:26:31 +0000
@@ -37,5 +37,10 @@
     mutter('export version %r', tree)
     inv = tree.inventory
     for dp, ie in inv.iter_entries():
+        # .bzrignore has no meaning outside of a working tree
+        # so do not export it
+        if dp == ".bzrignore":
+            continue
+        
         ie.put_on_disk(dest, dp, tree)
 

=== modified file 'bzrlib/export/tar_exporter.py'
--- bzrlib/export/tar_exporter.py	2005-11-14 23:58:51 +0000
+++ bzrlib/export/tar_exporter.py	2005-12-29 03:26:31 +0000
@@ -40,6 +40,11 @@
     mutter('export version %r', tree)
     inv = tree.inventory
     for dp, ie in inv.iter_entries():
+        # .bzrignore has no meaning outside of a working tree
+        # so do not export it
+        if dp == ".bzrignore":
+            continue
+        
         mutter("  export {%s} kind %s to %s", ie.file_id, ie.kind, dest)
         item, fileobj = ie.get_tar_item(root, dp, now, tree)
         ball.addfile(item, fileobj)

=== modified file 'bzrlib/export/zip_exporter.py'
--- bzrlib/export/zip_exporter.py	2005-12-01 17:53:57 +0000
+++ bzrlib/export/zip_exporter.py	2006-01-02 21:20:36 +0000
@@ -39,6 +39,10 @@
 
     try:
         for dp, ie in inv.iter_entries():
+            # .bzrignore has no meaning outside of a working tree
+            # so do not export it
+            if dp == ".bzrignore":
+                continue
 
             file_id = ie.file_id
             mutter("  export {%s} kind %s to %s", file_id, ie.kind, dest)

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2006-01-02 22:37:32 +0000
+++ bzrlib/osutils.py	2006-01-03 15:43:33 +0000
@@ -142,7 +142,7 @@
         # RBC 20060103 abstraction leakage: the paramiko SFTP clients rename
         # function raises an IOError with errno == None when a rename fails.
         # This then gets caught here.
-        if e.errno is not None:
+        if e.errno not in (None, errno.ENOENT, errno.ENOTDIR):
             raise
     except Exception, e:
         if (not hasattr(e, 'errno') 

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2005-10-17 23:13:00 +0000
+++ bzrlib/revisionspec.py	2005-12-30 20:54:47 +0000
@@ -204,7 +204,7 @@
         try:
             return RevisionInfo(branch, revs.index(self.spec) + 1, self.spec)
         except ValueError:
-            return RevisionInfo(branch, None)
+            return RevisionInfo(branch, None, self.spec)
 
 SPEC_TYPES.append(RevisionSpec_revid)
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2005-12-19 18:06:24 +0000
+++ bzrlib/tests/__init__.py	2005-12-29 02:36:07 +0000
@@ -679,7 +679,6 @@
                    'bzrlib.tests.test_plugins',
                    'bzrlib.tests.test_remove',
                    'bzrlib.tests.test_revision',
-                   'bzrlib.tests.test_revision_info',
                    'bzrlib.tests.test_revisionnamespaces',
                    'bzrlib.tests.test_revprops',
                    'bzrlib.tests.test_reweave',

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2005-12-11 22:05:21 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-01-03 15:33:37 +0000
@@ -29,11 +29,13 @@
 def test_suite():
     testmod_names = [
                      'bzrlib.tests.blackbox.test_cat',
-                     'bzrlib.tests.blackbox.test_too_much',
+                     'bzrlib.tests.blackbox.test_export',
+                     'bzrlib.tests.blackbox.test_missing',
                      'bzrlib.tests.blackbox.test_pull',
                      'bzrlib.tests.blackbox.test_revno',
+                     'bzrlib.tests.blackbox.test_revision_info',
+                     'bzrlib.tests.blackbox.test_too_much',
                      'bzrlib.tests.blackbox.test_versioning',
-                     'bzrlib.tests.blackbox.test_missing'
                      ]
     return TestLoader().loadTestsFromNames(testmod_names)
 

=== added file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_export.py	2005-12-30 03:25:20 +0000
@@ -0,0 +1,74 @@
+# -*- coding: utf-8 -*-
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+"""Black-box tests for bzr export.
+"""
+
+import os
+
+from bzrlib.branch import Branch
+from bzrlib.tests.blackbox import ExternalBase
+import tarfile, zipfile
+
+class TestExport(ExternalBase):
+
+    def test_tar_export(self):
+
+        os.mkdir('tar')
+        os.chdir('tar')
+
+        self.runbzr('init')
+        open('a', 'wb').write('foo\n')
+        self.runbzr('add a')
+        self.runbzr('ignore something')
+        self.runbzr('commit -m 1')
+        self.runbzr('export test.tar.gz')
+        ball = tarfile.open('test.tar.gz')
+        for m in ball.getnames():
+            #print m
+            self.failIf(os.path.basename(m) == '.bzrignore', 'tar export contains .bzrignore')
+
+    def test_zip_export(self):
+
+        os.mkdir('zip')
+        os.chdir('zip')
+
+        self.runbzr('init')
+        open('a', 'wb').write('foo\n')
+        self.runbzr('add a')
+        self.runbzr('ignore something')
+        self.runbzr('commit -m 1')
+        self.runbzr('export test.zip')
+        ball = zipfile.ZipFile('test.zip')
+        for m in ball.namelist():
+            #print m
+            self.failIf(os.path.basename(m) == '.bzrignore', 'zip export contains .bzrignore')
+
+    def test_dir_export(self):
+
+        os.mkdir('dir')
+        os.chdir('dir')
+
+        self.runbzr('init')
+        open('a', 'wb').write('foo\n')
+        self.runbzr('add a')
+        self.runbzr('ignore something')
+        self.runbzr('commit -m 1')
+        self.runbzr('export direxport')
+
+        files = sorted(os.listdir('direxport'))
+        self.assertEqual(['a'], files, 'dir contains .bzrignore')

=== renamed file 'bzrlib/tests/test_revision_info.py' => 'bzrlib/tests/blackbox/test_revision_info.py'
=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2005-12-01 21:49:24 +0000
+++ bzrlib/tests/test_config.py	2005-12-30 22:03:42 +0000
@@ -507,14 +507,24 @@
         self.my_config._get_global_config()._get_parser(global_file)
 
     def test_set_user_setting_sets_and_saves(self):
-        # TODO RBC 20051029 test hat mkdir ~/.bazaar is called ..
         self.get_location_config('/a/c')
         record = InstrumentedConfigObj("foo")
         self.my_config._parser = record
-        print ("test_set_user_setting_sets_and_saves broken: creates .bazaar "
-               "in the top-level directory, not inside the test directory")
-        return
-        self.my_config.set_user_option('foo', 'bar')
+
+        real_mkdir = os.mkdir
+        self.created = False
+        def checked_mkdir(path, mode=0777):
+            self.log('making directory: %s', path)
+            real_mkdir(path, mode)
+            self.created = True
+
+        os.mkdir = checked_mkdir
+        try:
+            self.my_config.set_user_option('foo', 'bar')
+        finally:
+            os.mkdir = real_mkdir
+
+        self.failUnless(self.created, 'Failed to create ~/.bazaar')
         self.assertEqual([('__contains__', '/a/c'),
                           ('__contains__', '/a/c/'),
                           ('__setitem__', '/a/c', {}),

=== modified file 'bzrlib/tests/test_revisionnamespaces.py'
--- bzrlib/tests/test_revisionnamespaces.py	2005-11-30 00:25:50 +0000
+++ bzrlib/tests/test_revisionnamespaces.py	2005-12-30 20:54:47 +0000
@@ -80,6 +80,10 @@
         self.assertEquals(RevisionSpec('ancestor:.').in_history(b3).rev_id,
                           'b@r-0-4')
 
+        # This should be in the revision store, but not in revision-history
+        self.assertEquals((None, 'b@r-0-4'),
+                RevisionSpec('revid:b@r-0-4').in_history(b))
+
     def test_branch_namespace(self):
         """Ensure that the branch namespace pulls in the requisite content."""
         self.build_tree(['branch1/', 'branch1/file', 'branch2/'])

